==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkImageDifference.java <==
// java wrapper for vtkImageDifference object
//

package vtk;
import vtk.*;

public class vtkImageDifference extends vtkThreadedImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetImageConnection_2(vtkAlgorithmOutput id0);
  public void SetImageConnection(vtkAlgorithmOutput id0)
    { SetImageConnection_2(id0); }

  private native void SetImageData_3(vtkDataObject id0);
  public void SetImageData(vtkDataObject id0)
    { SetImageData_3(id0); }

  private native long GetImage_4();
  public vtkImageData GetImage() {
    long temp = GetImage_4();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native double GetError_5();
  public double GetError()
    { return GetError_5(); }

  private native double GetThresholdedError_6();
  public double GetThresholdedError()
    { return GetThresholdedError_6(); }

  private native void SetThreshold_7(int id0);
  public void SetThreshold(int id0)
    { SetThreshold_7(id0); }

  private native int GetThreshold_8();
  public int GetThreshold()
    { return GetThreshold_8(); }

  private native void SetAllowShift_9(int id0);
  public void SetAllowShift(int id0)
    { SetAllowShift_9(id0); }

  private native int GetAllowShift_10();
  public int GetAllowShift()
    { return GetAllowShift_10(); }

  private native void AllowShiftOn_11();
  public void AllowShiftOn()
    { AllowShiftOn_11(); }

  private native void AllowShiftOff_12();
  public void AllowShiftOff()
    { AllowShiftOff_12(); }

  private native void SetAveraging_13(int id0);
  public void SetAveraging(int id0)
    { SetAveraging_13(id0); }

  private native int GetAveraging_14();
  public int GetAveraging()
    { return GetAveraging_14(); }

  private native void AveragingOn_15();
  public void AveragingOn()
    { AveragingOn_15(); }

  private native void AveragingOff_16();
  public void AveragingOff()
    { AveragingOff_16(); }

  public vtkImageDifference() { super(); }

  public vtkImageDifference(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkImageDifference.java <==
// java wrapper for vtkImageDifference object
//

package vtk;
import vtk.*;

public class vtkImageDifference extends vtkThreadedImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetImageConnection_2(vtkAlgorithmOutput id0);
  public void SetImageConnection(vtkAlgorithmOutput id0)
    { SetImageConnection_2(id0); }

  private native void SetImageData_3(vtkDataObject id0);
  public void SetImageData(vtkDataObject id0)
    { SetImageData_3(id0); }

  private native long GetImage_4();
  public vtkImageData GetImage() {
    long temp = GetImage_4();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native double GetError_5();
  public double GetError()
    { return GetError_5(); }

  private native double GetThresholdedError_6();
  public double GetThresholdedError()
    { return GetThresholdedError_6(); }

  private native void SetThreshold_7(int id0);
  public void SetThreshold(int id0)
    { SetThreshold_7(id0); }

  private native int GetThreshold_8();
  public int GetThreshold()
    { return GetThreshold_8(); }

  private native void SetAllowShift_9(int id0);
  public void SetAllowShift(int id0)
    { SetAllowShift_9(id0); }

  private native int GetAllowShift_10();
  public int GetAllowShift()
    { return GetAllowShift_10(); }

  private native void AllowShiftOn_11();
  public void AllowShiftOn()
    { AllowShiftOn_11(); }

  private native void AllowShiftOff_12();
  public void AllowShiftOff()
    { AllowShiftOff_12(); }

  private native void SetAveraging_13(int id0);
  public void SetAveraging(int id0)
    { SetAveraging_13(id0); }

  private native int GetAveraging_14();
  public int GetAveraging()
    { return GetAveraging_14(); }

  private native void AveragingOn_15();
  public void AveragingOn()
    { AveragingOn_15(); }

  private native void AveragingOff_16();
  public void AveragingOff()
    { AveragingOff_16(); }

  private native void SetAverageThresholdFactor_17(double id0);
  public void SetAverageThresholdFactor(double id0)
    { SetAverageThresholdFactor_17(id0); }

  private native double GetAverageThresholdFactor_18();
  public double GetAverageThresholdFactor()
    { return GetAverageThresholdFactor_18(); }

  public vtkImageDifference() { super(); }

  public vtkImageDifference(long id) { super(id); }
  public native long   VTKInit();

}
